@@ -2,16 +2,18 @@
 sentry
 ~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 import os
 import os.path
 
 try:
     VERSION = __import__('pkg_resources') \
         .get_distribution('sentry').version
-except Exception, e:
+except Exception as e:
     VERSION = 'unknown'
 
 
