@@ -2,14 +2,14 @@
 sentry.models.groupbookmark
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
 
 from django.conf import settings
-from django.db import models
 
-from sentry.db.models import Model, BaseManager, sane_repr
+from sentry.db.models import FlexibleForeignKey, Model, BaseManager, sane_repr
 
 
 class GroupBookmark(Model):
@@ -17,10 +17,10 @@ class GroupBookmark(Model):
     Identifies a bookmark relationship between a user and an
     aggregated event (Group).
     """
-    project = models.ForeignKey('sentry.Project', related_name="bookmark_set")
-    group = models.ForeignKey('sentry.Group', related_name="bookmark_set")
+    project = FlexibleForeignKey('sentry.Project', related_name="bookmark_set")
+    group = FlexibleForeignKey('sentry.Group', related_name="bookmark_set")
     # namespace related_name on User since we don't own the model
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="sentry_bookmark_set")
+    user = FlexibleForeignKey(settings.AUTH_USER_MODEL, related_name="sentry_bookmark_set")
 
     objects = BaseManager()
 
