@@ -8,8 +8,7 @@ sentry.rules.actions.notify_event
 
 from __future__ import absolute_import
 
-from sentry.plugins import plugins
-from sentry.plugins.bases.notify import Notification
+from sentry.plugins import Notification, plugins
 from sentry.rules.actions.base import EventAction
 from sentry.utils.safe import safe_execute
 
@@ -21,10 +20,15 @@ class NotifyEventAction(EventAction):
         from sentry.plugins.bases.notify import NotificationPlugin
 
         results = []
-        for plugin in plugins.for_project(self.project):
+        for plugin in plugins.for_project(self.project, version=1):
             if not isinstance(plugin, NotificationPlugin):
                 continue
             results.append(plugin)
+
+        for plugin in plugins.for_project(self.project, version=2):
+            for notifier in (safe_execute(plugin.get_notifiers) or ()):
+                results.append(notifier)
+
         return results
 
     def after(self, event, state):
